@@ -5,10 +5,10 @@
 import telegram
 
 class Telegram:
-    def __init__ (self, token):
+    def __init__ (self, token, chat_id = None):
         self.token = token
+        self.chat_id = chat_id
         self.bot = telegram.Bot(token = token)
-        self.chat_id = None
 
     def show_messages (self):
         updates = self.bot.getUpdates()
@@ -20,7 +20,7 @@ class Telegram:
 
     def send (self, msg, chat_id = None):
         msgs = self.updates ()
-        if msgs:
+        if msgs and self.chat_id is None:
             self.chat_id = msgs [-1].message.chat.id
 
         self.bot.sendMessage (
@@ -37,11 +37,12 @@ if __name__ == "__main__":
     token = os.environ.get ('TELEGRAM_TOKEN')
     if not token:
         raise SystemExit ('telegram token reqired')
+    chat_id = os.environ.get ('TELGRAM_CHAT_ID')
     commit_title = os.environ.get ("CI_COMMIT_TITLE", "")
     if commit_title.find ('--tg-silent') != -1:
         sys.exit ()
 
-    bot = Telegram (token)
+    bot = Telegram (token, chat_id)
     for i in range (7):
         try:
             bot.send (' '.join (sys.argv [1:]))
